# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

"""
This module contains X Ray User Manager main run function
"""
from socket import socket, AF_UNIX, SOCK_STREAM

from xray.cli_utils.cmdline_parser import cmd_parser_user_manager, \
    parse_cmd_arguments
from xray.cli_utils.validations import validate_user
from xray.internal.constants import user_agent_sock
from xray.internal.user_plugin_utils import pack_request, unpack_response, \
    check_for_root, error_response


def executed_as_root_check() -> None:
    """
    Check if User Manager is executed as root and throw error in case if yes
    """
    if check_for_root():
        raise SystemExit(
            error_response('X-Ray User Manager cannot be executed as root'))


def run() -> None:
    """
    Main run function
    """
    executed_as_root_check()
    args = parse_cmd_arguments(cmd_parser_user_manager())
    validated_args = validate_user(args.__dict__)
    to_send = pack_request(validated_args.__dict__)
    with socket(AF_UNIX, SOCK_STREAM) as s:
        try:
            s.connect(user_agent_sock)
        except (ConnectionError, OSError):
            raise SystemExit(error_response(
                'X-Ray User Plugin is not enabled. Please, contact your server administrator'))
        s.sendall(to_send.encode())
        data = unpack_response(s)
    print(data.decode())
