#!/opt/alt/python37/bin/python3 -Ibb
# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

"""
Main cloudlinux-xray-migrate utility script
"""
import argparse
import os
import sys

from xray.internal.utils import configure_logging
from xray.reconfiguration.migrate import (
    stop_tasks,
    continue_tasks,
    marker,
    migration_log
)

if __name__ == '__main__':
    parser = argparse.ArgumentParser(prog='cloudlinux-xray-migrator',
                                     description='Utility to migrate X-Ray Tasks')
    parser.add_argument('--stop', dest="stop", action="store_true",
                        default=False, help='stop all running tasks')
    parser.add_argument('--continue', dest="resume", action="store_true",
                        default=False,
                        help='continue tasks from the saved during stop list')
    parser.add_argument('--force', dest="force", action="store_true",
                        default=False,
                        help='ignore existing migration marker and perform operation anyway')

    opts = parser.parse_args()

    if os.path.isfile(marker) and not opts.force:
        # skip migration if marker found and no force argument given
        sys.exit(0)

    configure_logging(migration_log)

    if opts.stop:
        stop_tasks()
    if opts.resume:
        continue_tasks()
